using System;
using System.Collections;
using System.IO;
using System.Xml;

namespace UI
{
	/// <summary>
	/// Description rsume de ConfigManager.
	/// </summary>
	public class ConfigManager
	{
		private String  _configFilename;
		private String  _folderName;
		private ArrayList _xmlElements;

		#region Constructeur ConfigManager
		/// <summary>
		/// Constructeur de la classe ConfigManager
		/// </summary>
		public ConfigManager(String configFilename, String appFolder)
		{
			// Sauvegarde du nom du repertoire au enregistrer le fichier de config
			_configFilename = configFilename;
			_folderName = appFolder;

			// Defintion du repertoire courant au repertoire application data de l user
			Environment.CurrentDirectory = Environment.GetEnvironmentVariable("APPDATA");

			// Creation du repertoire LogSearcher dans le repertoire ApplicationData de l'utilisateur
			if(!Directory.Exists(@".\" + _folderName))
				Directory.CreateDirectory(_folderName);
		}
		#endregion

		#region SaveConfiguration
		/// <summary>
		/// Methode qui a pour rle de sauvegarder la configuration (options, langue, etc)
		/// </summary>
		public void SaveConfiguration()
		{
			// Recuperation repertoire data de l'utilisateur
			string save = Environment.CurrentDirectory;

			// Defintion du repertoire courant au repertoire application data de l user
			Environment.CurrentDirectory = Environment.GetEnvironmentVariable("APPDATA");

			try
			{
				XmlTextWriter writerXML = new XmlTextWriter(@".\" + _folderName + @"\" + _configFilename, System.Text.Encoding.Unicode);
				writerXML.Formatting = Formatting.Indented;

				// Demarrage de l'ecriture
				writerXML.WriteStartDocument(false);
			
				// Ouverture balise racine
				writerXML.WriteStartElement("config");
			
				// Enregistrement des nodes
				foreach(ConfigElement temp in _xmlElements)
				{
					// Balise language
					writerXML.WriteStartElement(temp.GetNodeName());
					writerXML.WriteString(temp.GetNodeValue());
					writerXML.WriteEndElement();
				}

				// Fermeture balise racine
				writerXML.WriteEndElement();

				// Fermeture et enregistrement du fichier
				writerXML.Flush();
				writerXML.Close();
			}
			catch
			{

			}

			// Restauration repertoire courant
			Environment.CurrentDirectory = save;
		}
		#endregion

		#region LoadConfiguration
		/// <summary>
		/// Methode qui a pour rle de charger la configuration, option etc...
		/// </summary>
		public void LoadConfiguration()
		{
			// Recuperation repertoire data de l'utilisateur
			string save = Environment.CurrentDirectory;
			//Defintion du repertoire courant au repertoire application data de l user
			Environment.CurrentDirectory = Environment.GetEnvironmentVariable("APPDATA");

			// Collection qui va contenir les infos du fichier
			ArrayList configInfo = new ArrayList();
			
			// Initialisation du StreamReader
			StreamReader flux = null;

			// Test de l'existence du fichier de conf
			if(File.Exists(@".\" + _folderName + @"\" + _configFilename))
			{
				try
				{
					flux = new StreamReader(@".\" + _folderName + @"\" + _configFilename);
					XmlTextReader lecteur = new XmlTextReader (flux);
				
					// Lecture du flux
					while (lecteur.Read()) 
					{
						switch (lecteur.NodeType) 
						{
								// Le noeud est un element 
							case XmlNodeType.Element: 
								while (lecteur.MoveToNextAttribute());
								break;
								// C'est le texte de l'element
							case XmlNodeType.Text: 
								ConfigElement temp = new ConfigElement(lecteur.Name, lecteur.Value);
								configInfo.Add(temp);
								break;
								// Afficher la fin de l'lment.
							case XmlNodeType.EndElement: 
								break;
						}
					} // Lecture termine
				}
				catch{}
				finally
				{
					// Fermeture du flux
					flux.Close();
				}
			}

			// Restauration repertoire
			Environment.CurrentDirectory = save;

			// Retour du resultat
			_xmlElements = configInfo;
		}
		#endregion

		/// <summary>
		/// Getter pour recuperer la configuration charg
		/// </summary>
		/// <returns>Collections d'elements ConfigElement</returns>
		public ArrayList GetConfig()
		{
			return _xmlElements;
		}

		/// <summary>
		/// Setter pour modifier la configuration
		/// </summary>
		/// <param name="configElement">Collections d'elements ConfigElement</param>
		public void SetConfig(ArrayList configElement)
		{
			_xmlElements = configElement;
		}
	}
}
