using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Diagnostics;

namespace UI
{
	public class frmEveTimer : System.Windows.Forms.Form
    {
        private System.ComponentModel.IContainer components;

		private int m_minutes;
        private frmTimerDisplay m_timerWindow;
        private System.Windows.Forms.ColorDialog cldColorChoice;

		// Couleurs
		public Color m_fontColor = Color.Black;
		public Color m_backColor = Color.Empty;
        public Color m_blinkColor = Color.Red;

		// Always on top
		private bool m_TimerAlwaysOnTop = true;

		// Config Manager
        private ConfigManager mAppConfig;
        private System.Windows.Forms.NotifyIcon notifyIcon;

		// Taille selectionne
        private bool m_minimizeSystray;
        private TabPage tbpOptions;
        private GroupBox gbxOptions;
        private CheckBox cbxMinimize;
        private CheckBox cbxAlwaysOnTop;
        private TabPage tbpColors;
        private GroupBox groupBox1;
        private Panel pnlHighlightFont;
        private Panel pnlFonts;
        private Panel pnlBackground;
        private Button btnHighlightFont;
        private Button btnFontsColors;
        private Button btnBackgroundColor;
        private TabPage tbpTimer;
        private Button btnStartStop;
        private GroupBox gbxTimerBox;
        private Label lblMinutes;
        private TextBox tbxTimer;
        private RadioButton rdbCustomized;
        private RadioButton rdbCriminal;
        private RadioButton rdbAggroTimer;
        private TabControl tclLayout;
        private Label label1;
        private MenuItem mniAggroTimer;
        private MenuItem mniCriminal;
        private MenuItem mniStart;
        private MenuItem menuItem2;
        private MenuItem mniMinimize;
        private MenuItem mniMaximize;
        private MenuItem menuItem5;
        private MenuItem mniExit;
        private ContextMenu ctxMenuMain;
        private LinkLabel linkLabel1;
        private Button btnResetSettings;
        private Button btnClearColor;
		private bool m_disableNotifyClickEvent;

		public frmEveTimer()
		{
			//
			// Requis pour la prise en charge du Concepteur Windows Forms
			//
			InitializeComponent();

			// Init de la form
			this.m_minutes = 3;
			rdbAggroTimer.Checked = true;
			tbxTimer.Enabled = false;
			lblMinutes.Enabled = false;

			// Chargement de la config
			mAppConfig = new ConfigManager("config.xml", "Fullscreen Countdown");
			mAppConfig.LoadConfiguration();

			// Application de la configuration
			ArrayList configValues = mAppConfig.GetConfig();

			// Si la configuration a t charge
			if(configValues != null && configValues.Count > 2)
			{
				// Recuperation des valeurs des couleurs
				string fontColor = ((ConfigElement)configValues[0]).GetNodeValue();
				string backColor = ((ConfigElement)configValues[1]).GetNodeValue();
				string blinkColor = ((ConfigElement)configValues[2]).GetNodeValue();

				// Determine la validit de la couleur puis conversion
				Color tempFontColor = Color.FromName(fontColor);
				Color tempBackColor = Color.FromName(backColor);
				Color tempBlinkColor = Color.FromName(blinkColor);
				
				// Si ce n'est pas une couleur connu sous forme texte, conversion
				if(!tempFontColor.IsKnownColor)
				{
					tempFontColor = Color.FromArgb(Convert.ToInt32(fontColor, 16));
				}
				if(!tempBackColor.IsKnownColor)
				{
					tempBackColor = Color.FromArgb(Convert.ToInt32(backColor, 16));
				}
				if(!tempBlinkColor.IsKnownColor)
				{
					tempBlinkColor = Color.FromArgb(Convert.ToInt32(blinkColor, 16));
				}

				// Couleurs finales
				m_backColor = tempBackColor;
				m_blinkColor = tempBlinkColor;
				m_fontColor = tempFontColor;
				
				// MAJ des icones
				pnlBackground.BackColor = m_backColor;
				pnlFonts.BackColor = m_fontColor;
				pnlHighlightFont.BackColor = m_blinkColor;
			}

			// Fenetre du timer
			m_timerWindow = new frmTimerDisplay(this);
			m_timerWindow.Hide();

			// Restauration des positions, si les valeurs ont t chargs du fichier
			if(configValues != null && configValues.Count > 6)
			{
				try
				{
					// Stockage des positions des fenetres
					int mainX = Convert.ToInt32( ((ConfigElement)configValues[3]).GetNodeValue() );
					int mainY = Convert.ToInt32( ((ConfigElement)configValues[4]).GetNodeValue() );
					int timerX = Convert.ToInt32( ((ConfigElement)configValues[5]).GetNodeValue() );
					int timerY = Convert.ToInt32( ((ConfigElement)configValues[6]).GetNodeValue() );

					// Application des positions rcuprs
					this.StartPosition = FormStartPosition.Manual;
					this.Location = new Point(mainX, mainY);

					m_timerWindow.StartPosition = FormStartPosition.Manual;
					m_timerWindow.Location = new Point(timerX, timerY);
				}
				catch
				{
					// Valeurs de positions incorrectes
					this.StartPosition = FormStartPosition.CenterScreen;
					m_timerWindow.StartPosition = FormStartPosition.CenterParent;
				}
			}

			// Chargement de la taille
			if(configValues != null && configValues.Count > 8)
			{
				int windowsWidth = Convert.ToInt32( ((ConfigElement)configValues[7]).GetNodeValue() );
				int windowsHeight = Convert.ToInt32( ((ConfigElement)configValues[8]).GetNodeValue() );
				m_timerWindow.Size = new Size(windowsWidth, windowsHeight);
			}

			// Chargement de la valeur du always on top
			if(configValues != null && configValues.Count > 9)
			{
				m_TimerAlwaysOnTop = Convert.ToBoolean( ((ConfigElement)configValues[9]).GetNodeValue() );
				cbxAlwaysOnTop.Checked = m_TimerAlwaysOnTop;
			}

			// Chargement de la valeur du always on top
			if(configValues != null && configValues.Count > 10)
			{
				m_minimizeSystray = Convert.ToBoolean( ((ConfigElement)configValues[10]).GetNodeValue() );
				cbxMinimize.Checked = m_minimizeSystray;
			}

			// Assignation du contexte menu principal
			notifyIcon.ContextMenu = ctxMenuMain;
		}

		/// <summary>
		/// Nettoyage des ressources utilises.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Code gnr par le Concepteur Windows Form
		/// <summary>
		/// Mthode requise pour la prise en charge du concepteur - ne modifiez pas
		/// le contenu de cette mthode avec l'diteur de code.
		/// </summary>
		private void InitializeComponent()
		{
            this.components = new System.ComponentModel.Container();
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(frmEveTimer));
            this.cldColorChoice = new System.Windows.Forms.ColorDialog();
            this.notifyIcon = new System.Windows.Forms.NotifyIcon(this.components);
            this.tbpOptions = new System.Windows.Forms.TabPage();
            this.gbxOptions = new System.Windows.Forms.GroupBox();
            this.btnResetSettings = new System.Windows.Forms.Button();
            this.linkLabel1 = new System.Windows.Forms.LinkLabel();
            this.label1 = new System.Windows.Forms.Label();
            this.cbxMinimize = new System.Windows.Forms.CheckBox();
            this.cbxAlwaysOnTop = new System.Windows.Forms.CheckBox();
            this.tbpColors = new System.Windows.Forms.TabPage();
            this.groupBox1 = new System.Windows.Forms.GroupBox();
            this.btnClearColor = new System.Windows.Forms.Button();
            this.pnlHighlightFont = new System.Windows.Forms.Panel();
            this.pnlFonts = new System.Windows.Forms.Panel();
            this.pnlBackground = new System.Windows.Forms.Panel();
            this.btnHighlightFont = new System.Windows.Forms.Button();
            this.btnFontsColors = new System.Windows.Forms.Button();
            this.btnBackgroundColor = new System.Windows.Forms.Button();
            this.tbpTimer = new System.Windows.Forms.TabPage();
            this.btnStartStop = new System.Windows.Forms.Button();
            this.gbxTimerBox = new System.Windows.Forms.GroupBox();
            this.lblMinutes = new System.Windows.Forms.Label();
            this.tbxTimer = new System.Windows.Forms.TextBox();
            this.rdbCustomized = new System.Windows.Forms.RadioButton();
            this.rdbCriminal = new System.Windows.Forms.RadioButton();
            this.rdbAggroTimer = new System.Windows.Forms.RadioButton();
            this.tclLayout = new System.Windows.Forms.TabControl();
            this.mniAggroTimer = new System.Windows.Forms.MenuItem();
            this.mniCriminal = new System.Windows.Forms.MenuItem();
            this.mniStart = new System.Windows.Forms.MenuItem();
            this.menuItem2 = new System.Windows.Forms.MenuItem();
            this.mniMinimize = new System.Windows.Forms.MenuItem();
            this.mniMaximize = new System.Windows.Forms.MenuItem();
            this.menuItem5 = new System.Windows.Forms.MenuItem();
            this.mniExit = new System.Windows.Forms.MenuItem();
            this.ctxMenuMain = new System.Windows.Forms.ContextMenu();
            this.tbpOptions.SuspendLayout();
            this.gbxOptions.SuspendLayout();
            this.tbpColors.SuspendLayout();
            this.groupBox1.SuspendLayout();
            this.tbpTimer.SuspendLayout();
            this.gbxTimerBox.SuspendLayout();
            this.tclLayout.SuspendLayout();
            this.SuspendLayout();
            // 
            // cldColorChoice
            // 
            this.cldColorChoice.AllowFullOpen = false;
            this.cldColorChoice.SolidColorOnly = true;
            // 
            // notifyIcon
            // 
            this.notifyIcon.Icon = ((System.Drawing.Icon)(resources.GetObject("notifyIcon.Icon")));
            this.notifyIcon.Text = "Fullscreen Countdown";
            this.notifyIcon.Visible = true;
            this.notifyIcon.DoubleClick += new System.EventHandler(this.notifyIcon_DoubleClick);
            // 
            // tbpOptions
            // 
            this.tbpOptions.Controls.Add(this.gbxOptions);
            this.tbpOptions.Location = new System.Drawing.Point(4, 22);
            this.tbpOptions.Name = "tbpOptions";
            this.tbpOptions.Size = new System.Drawing.Size(291, 181);
            this.tbpOptions.TabIndex = 2;
            this.tbpOptions.Text = "Options";
            // 
            // gbxOptions
            // 
            this.gbxOptions.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
                        | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.gbxOptions.Controls.Add(this.btnResetSettings);
            this.gbxOptions.Controls.Add(this.linkLabel1);
            this.gbxOptions.Controls.Add(this.label1);
            this.gbxOptions.Controls.Add(this.cbxMinimize);
            this.gbxOptions.Controls.Add(this.cbxAlwaysOnTop);
            this.gbxOptions.Location = new System.Drawing.Point(8, 8);
            this.gbxOptions.Name = "gbxOptions";
            this.gbxOptions.Size = new System.Drawing.Size(275, 165);
            this.gbxOptions.TabIndex = 0;
            this.gbxOptions.TabStop = false;
            this.gbxOptions.Text = "Miscelleanous";
            // 
            // btnResetSettings
            // 
            this.btnResetSettings.Location = new System.Drawing.Point(65, 86);
            this.btnResetSettings.Name = "btnResetSettings";
            this.btnResetSettings.Size = new System.Drawing.Size(145, 23);
            this.btnResetSettings.TabIndex = 4;
            this.btnResetSettings.Text = "Reset positions/sizes";
            this.btnResetSettings.UseVisualStyleBackColor = true;
            this.btnResetSettings.Click += new System.EventHandler(this.btnResetSettings_Click);
            // 
            // linkLabel1
            // 
            this.linkLabel1.AutoSize = true;
            this.linkLabel1.Location = new System.Drawing.Point(13, 137);
            this.linkLabel1.Name = "linkLabel1";
            this.linkLabel1.Size = new System.Drawing.Size(248, 13);
            this.linkLabel1.TabIndex = 3;
            this.linkLabel1.TabStop = true;
            this.linkLabel1.Text = "http://fullscreencountdown.codeplex.com/";
            this.linkLabel1.LinkClicked += new System.Windows.Forms.LinkLabelLinkClickedEventHandler(this.linkLabel1_LinkClicked);
            // 
            // label1
            // 
            this.label1.AutoSize = true;
            this.label1.Location = new System.Drawing.Point(13, 115);
            this.label1.Name = "label1";
            this.label1.Size = new System.Drawing.Size(179, 13);
            this.label1.TabIndex = 2;
            this.label1.Text = "Contact : gismork@gmail.com";
            // 
            // cbxMinimize
            // 
            this.cbxMinimize.Location = new System.Drawing.Point(16, 56);
            this.cbxMinimize.Name = "cbxMinimize";
            this.cbxMinimize.Size = new System.Drawing.Size(160, 24);
            this.cbxMinimize.TabIndex = 1;
            this.cbxMinimize.Text = "Minimize in the systray";
            this.cbxMinimize.CheckedChanged += new System.EventHandler(this.cbxMinimize_CheckedChanged);
            // 
            // cbxAlwaysOnTop
            // 
            this.cbxAlwaysOnTop.Checked = true;
            this.cbxAlwaysOnTop.CheckState = System.Windows.Forms.CheckState.Checked;
            this.cbxAlwaysOnTop.Location = new System.Drawing.Point(16, 24);
            this.cbxAlwaysOnTop.Name = "cbxAlwaysOnTop";
            this.cbxAlwaysOnTop.Size = new System.Drawing.Size(144, 24);
            this.cbxAlwaysOnTop.TabIndex = 0;
            this.cbxAlwaysOnTop.Text = "Timer always on top";
            this.cbxAlwaysOnTop.CheckedChanged += new System.EventHandler(this.cbxAlwaysOnTop_CheckedChanged);
            // 
            // tbpColors
            // 
            this.tbpColors.Controls.Add(this.groupBox1);
            this.tbpColors.Font = new System.Drawing.Font("Verdana", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.tbpColors.Location = new System.Drawing.Point(4, 22);
            this.tbpColors.Name = "tbpColors";
            this.tbpColors.Size = new System.Drawing.Size(291, 181);
            this.tbpColors.TabIndex = 1;
            this.tbpColors.Text = "Colors";
            // 
            // groupBox1
            // 
            this.groupBox1.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
                        | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.groupBox1.Controls.Add(this.btnClearColor);
            this.groupBox1.Controls.Add(this.pnlHighlightFont);
            this.groupBox1.Controls.Add(this.pnlFonts);
            this.groupBox1.Controls.Add(this.pnlBackground);
            this.groupBox1.Controls.Add(this.btnHighlightFont);
            this.groupBox1.Controls.Add(this.btnFontsColors);
            this.groupBox1.Controls.Add(this.btnBackgroundColor);
            this.groupBox1.Location = new System.Drawing.Point(8, 8);
            this.groupBox1.Name = "groupBox1";
            this.groupBox1.Size = new System.Drawing.Size(275, 165);
            this.groupBox1.TabIndex = 1;
            this.groupBox1.TabStop = false;
            this.groupBox1.Text = "Colors";
            // 
            // btnClearColor
            // 
            this.btnClearColor.Location = new System.Drawing.Point(214, 24);
            this.btnClearColor.Name = "btnClearColor";
            this.btnClearColor.Size = new System.Drawing.Size(52, 23);
            this.btnClearColor.TabIndex = 9;
            this.btnClearColor.Text = "Clear";
            this.btnClearColor.Click += new System.EventHandler(this.btnClearColor_Click);
            // 
            // pnlHighlightFont
            // 
            this.pnlHighlightFont.BackColor = System.Drawing.Color.Red;
            this.pnlHighlightFont.Location = new System.Drawing.Point(16, 120);
            this.pnlHighlightFont.Name = "pnlHighlightFont";
            this.pnlHighlightFont.Size = new System.Drawing.Size(24, 24);
            this.pnlHighlightFont.TabIndex = 8;
            // 
            // pnlFonts
            // 
            this.pnlFonts.BackColor = System.Drawing.Color.Black;
            this.pnlFonts.Location = new System.Drawing.Point(16, 72);
            this.pnlFonts.Name = "pnlFonts";
            this.pnlFonts.Size = new System.Drawing.Size(24, 24);
            this.pnlFonts.TabIndex = 7;
            // 
            // pnlBackground
            // 
            this.pnlBackground.BackColor = System.Drawing.SystemColors.Control;
            this.pnlBackground.Location = new System.Drawing.Point(16, 24);
            this.pnlBackground.Name = "pnlBackground";
            this.pnlBackground.Size = new System.Drawing.Size(24, 24);
            this.pnlBackground.TabIndex = 6;
            // 
            // btnHighlightFont
            // 
            this.btnHighlightFont.Location = new System.Drawing.Point(69, 120);
            this.btnHighlightFont.Name = "btnHighlightFont";
            this.btnHighlightFont.Size = new System.Drawing.Size(136, 23);
            this.btnHighlightFont.TabIndex = 4;
            this.btnHighlightFont.Text = "Highlight font";
            this.btnHighlightFont.Click += new System.EventHandler(this.btnHighlightFont_Click);
            // 
            // btnFontsColors
            // 
            this.btnFontsColors.Location = new System.Drawing.Point(69, 72);
            this.btnFontsColors.Name = "btnFontsColors";
            this.btnFontsColors.Size = new System.Drawing.Size(136, 23);
            this.btnFontsColors.TabIndex = 1;
            this.btnFontsColors.Text = "Fonts";
            this.btnFontsColors.Click += new System.EventHandler(this.btnFontsColord_Click);
            // 
            // btnBackgroundColor
            // 
            this.btnBackgroundColor.Location = new System.Drawing.Point(69, 24);
            this.btnBackgroundColor.Name = "btnBackgroundColor";
            this.btnBackgroundColor.Size = new System.Drawing.Size(136, 23);
            this.btnBackgroundColor.TabIndex = 0;
            this.btnBackgroundColor.Text = "Background";
            this.btnBackgroundColor.Click += new System.EventHandler(this.btnBackgroundColor_Click);
            // 
            // tbpTimer
            // 
            this.tbpTimer.Controls.Add(this.btnStartStop);
            this.tbpTimer.Controls.Add(this.gbxTimerBox);
            this.tbpTimer.Font = new System.Drawing.Font("Verdana", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.tbpTimer.Location = new System.Drawing.Point(4, 22);
            this.tbpTimer.Name = "tbpTimer";
            this.tbpTimer.Size = new System.Drawing.Size(291, 181);
            this.tbpTimer.TabIndex = 0;
            this.tbpTimer.Text = "Timer";
            // 
            // btnStartStop
            // 
            this.btnStartStop.FlatStyle = System.Windows.Forms.FlatStyle.System;
            this.btnStartStop.Location = new System.Drawing.Point(97, 149);
            this.btnStartStop.Name = "btnStartStop";
            this.btnStartStop.Size = new System.Drawing.Size(96, 24);
            this.btnStartStop.TabIndex = 1;
            this.btnStartStop.Text = "Start";
            this.btnStartStop.Click += new System.EventHandler(this.btnStartStop_Click);
            // 
            // gbxTimerBox
            // 
            this.gbxTimerBox.Controls.Add(this.lblMinutes);
            this.gbxTimerBox.Controls.Add(this.tbxTimer);
            this.gbxTimerBox.Controls.Add(this.rdbCustomized);
            this.gbxTimerBox.Controls.Add(this.rdbCriminal);
            this.gbxTimerBox.Controls.Add(this.rdbAggroTimer);
            this.gbxTimerBox.Font = new System.Drawing.Font("Verdana", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.gbxTimerBox.Location = new System.Drawing.Point(4, 8);
            this.gbxTimerBox.Name = "gbxTimerBox";
            this.gbxTimerBox.Size = new System.Drawing.Size(279, 135);
            this.gbxTimerBox.TabIndex = 0;
            this.gbxTimerBox.TabStop = false;
            this.gbxTimerBox.Text = "Timer choice";
            // 
            // lblMinutes
            // 
            this.lblMinutes.Enabled = false;
            this.lblMinutes.Location = new System.Drawing.Point(80, 99);
            this.lblMinutes.Name = "lblMinutes";
            this.lblMinutes.Size = new System.Drawing.Size(128, 19);
            this.lblMinutes.TabIndex = 4;
            this.lblMinutes.Text = "Minutes (max 999)";
            // 
            // tbxTimer
            // 
            this.tbxTimer.Enabled = false;
            this.tbxTimer.Location = new System.Drawing.Point(32, 96);
            this.tbxTimer.MaxLength = 3;
            this.tbxTimer.Name = "tbxTimer";
            this.tbxTimer.Size = new System.Drawing.Size(40, 21);
            this.tbxTimer.TabIndex = 3;
            this.tbxTimer.Text = "180";
            this.tbxTimer.TextChanged += new System.EventHandler(this.tbxTimer_TextChanged);
            // 
            // rdbCustomized
            // 
            this.rdbCustomized.Location = new System.Drawing.Point(16, 72);
            this.rdbCustomized.Name = "rdbCustomized";
            this.rdbCustomized.Size = new System.Drawing.Size(104, 24);
            this.rdbCustomized.TabIndex = 2;
            this.rdbCustomized.Text = "Customized";
            this.rdbCustomized.CheckedChanged += new System.EventHandler(this.TimerChoiceCheckedChanged);
            // 
            // rdbCriminal
            // 
            this.rdbCriminal.Location = new System.Drawing.Point(16, 48);
            this.rdbCriminal.Name = "rdbCriminal";
            this.rdbCriminal.Size = new System.Drawing.Size(192, 24);
            this.rdbCriminal.TabIndex = 1;
            this.rdbCriminal.Text = "10 Minutes";
            this.rdbCriminal.CheckedChanged += new System.EventHandler(this.TimerChoiceCheckedChanged);
            // 
            // rdbAggroTimer
            // 
            this.rdbAggroTimer.Checked = true;
            this.rdbAggroTimer.Location = new System.Drawing.Point(16, 24);
            this.rdbAggroTimer.Name = "rdbAggroTimer";
            this.rdbAggroTimer.Size = new System.Drawing.Size(168, 24);
            this.rdbAggroTimer.TabIndex = 0;
            this.rdbAggroTimer.TabStop = true;
            this.rdbAggroTimer.Text = "3 Minutes";
            this.rdbAggroTimer.CheckedChanged += new System.EventHandler(this.TimerChoiceCheckedChanged);
            // 
            // tclLayout
            // 
            this.tclLayout.Controls.Add(this.tbpTimer);
            this.tclLayout.Controls.Add(this.tbpColors);
            this.tclLayout.Controls.Add(this.tbpOptions);
            this.tclLayout.Dock = System.Windows.Forms.DockStyle.Fill;
            this.tclLayout.Location = new System.Drawing.Point(0, 0);
            this.tclLayout.Name = "tclLayout";
            this.tclLayout.SelectedIndex = 0;
            this.tclLayout.Size = new System.Drawing.Size(299, 207);
            this.tclLayout.TabIndex = 7;
            // 
            // mniAggroTimer
            // 
            this.mniAggroTimer.Index = 0;
            this.mniAggroTimer.Text = "3 Minutes";
            this.mniAggroTimer.Click += new System.EventHandler(this.mniAggroTimer_Click);
            // 
            // mniCriminal
            // 
            this.mniCriminal.Index = 1;
            this.mniCriminal.Text = "10 minutes";
            this.mniCriminal.Click += new System.EventHandler(this.mniCriminal_Click);
            // 
            // mniStart
            // 
            this.mniStart.Index = 0;
            this.mniStart.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
            this.mniAggroTimer,
            this.mniCriminal});
            this.mniStart.Text = "Start";
            // 
            // menuItem2
            // 
            this.menuItem2.Index = 1;
            this.menuItem2.Text = "-";
            // 
            // mniMinimize
            // 
            this.mniMinimize.Index = 2;
            this.mniMinimize.Text = "Minimize";
            this.mniMinimize.Click += new System.EventHandler(this.mniMinimize_Click);
            // 
            // mniMaximize
            // 
            this.mniMaximize.Index = 3;
            this.mniMaximize.Text = "Maximize";
            this.mniMaximize.Click += new System.EventHandler(this.mniMaximize_Click);
            // 
            // menuItem5
            // 
            this.menuItem5.Index = 4;
            this.menuItem5.Text = "-";
            // 
            // mniExit
            // 
            this.mniExit.Index = 5;
            this.mniExit.Text = "Exit";
            this.mniExit.Click += new System.EventHandler(this.mniExit_Click);
            // 
            // ctxMenuMain
            // 
            this.ctxMenuMain.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
            this.mniStart,
            this.menuItem2,
            this.mniMinimize,
            this.mniMaximize,
            this.menuItem5,
            this.mniExit});
            // 
            // frmEveTimer
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(6, 14);
            this.ClientSize = new System.Drawing.Size(299, 207);
            this.Controls.Add(this.tclLayout);
            this.Font = new System.Drawing.Font("Verdana", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
            this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
            this.MaximizeBox = false;
            this.MinimumSize = new System.Drawing.Size(254, 230);
            this.Name = "frmEveTimer";
            this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
            this.Text = "Fullscreen Countdown";
            this.Closing += new System.ComponentModel.CancelEventHandler(this.frmEveTimer_Closing);
            this.tbpOptions.ResumeLayout(false);
            this.gbxOptions.ResumeLayout(false);
            this.gbxOptions.PerformLayout();
            this.tbpColors.ResumeLayout(false);
            this.groupBox1.ResumeLayout(false);
            this.tbpTimer.ResumeLayout(false);
            this.gbxTimerBox.ResumeLayout(false);
            this.gbxTimerBox.PerformLayout();
            this.tclLayout.ResumeLayout(false);
            this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// Point d'entre principal de l'application.
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new frmEveTimer());
		}

		private void TimerChoiceCheckedChanged(object sender, System.EventArgs e)
		{
			// Determination du temps choisi
			if(rdbAggroTimer.Checked)
			{
				this.m_minutes = 3;
			}

			// Criminal
			if(rdbCriminal.Checked)
			{
				this.m_minutes = 10;	
			}

			// Customized
			if(rdbCustomized.Checked)
			{
				tbxTimer.Enabled = true;
				lblMinutes.Enabled = true;
			}
			else
			{
				tbxTimer.Enabled = false;
				lblMinutes.Enabled = false;
			}

			// Desactivation bouton start
			if(tbxTimer.Text == String.Empty && tbxTimer.Enabled == true)
			{
				btnStartStop.Enabled = false;
			}
			else
			{
				btnStartStop.Enabled = true;
			}
		}

		private void btnStartStop_Click(object sender, System.EventArgs e)
		{
			// Recuperation de la valeur de temps si customize
			if(rdbCustomized.Checked)
			{
				this.m_minutes = Int32.Parse(tbxTimer.Text);
			}

			StartTimer(this.m_minutes);
		}

		private void StartTimer(int minutes)
		{
			this.Hide();
			
			// Application couleurs 
			m_timerWindow.SetBackColor(m_backColor);
			m_timerWindow.SetFontColor(m_fontColor);
			m_timerWindow.SetBlinkColor(m_blinkColor);

			// Affichage fenetre timer
			m_timerWindow.Show();
			m_timerWindow.SetAlwaysOnTop(m_TimerAlwaysOnTop);

			m_timerWindow.SetMinutes(minutes);
			m_timerWindow.StartCount();
			m_timerWindow.SetSizable();
			m_timerWindow.SetTimerFontSize();

			// Mise en place du contexte menu appropri
			notifyIcon.ContextMenu = m_timerWindow.GetTimerContext();
			m_disableNotifyClickEvent = true;
		}

		private void tbxTimer_TextChanged(object sender, System.EventArgs e)
		{
			// Controle de la zone d'edition
			try
			{
				this.m_minutes = Convert.ToInt32(tbxTimer.Text);
			}
			catch
			{
				// Contenu incorret
				tbxTimer.Clear();
			}

			// Desactivation bouton start
			if(tbxTimer.Text == String.Empty)
			{
				btnStartStop.Enabled = false;
			}
			else
			{
				btnStartStop.Enabled = true;
			}
		}

		private void btnFontsColord_Click(object sender, System.EventArgs e)
		{
			if(cldColorChoice.ShowDialog() == DialogResult.OK)
			{
				// Set the control's font.
				pnlFonts.BackColor = cldColorChoice.Color;
				m_fontColor = cldColorChoice.Color;
			}

		}

		private void btnBackgroundColor_Click(object sender, System.EventArgs e)
		{
			if(cldColorChoice.ShowDialog() == DialogResult.OK)
			{
				// Set the control's font.
				pnlBackground.BackColor = cldColorChoice.Color;
				m_backColor = cldColorChoice.Color;
			}
		}

		private void btnHighlightFont_Click(object sender, System.EventArgs e)
		{
			if(cldColorChoice.ShowDialog() == DialogResult.OK)
			{
				// Set the control's font.
				pnlHighlightFont.BackColor = cldColorChoice.Color;
				m_blinkColor = cldColorChoice.Color;
			}
		}

		private void frmEveTimer_Closing(object sender, System.ComponentModel.CancelEventArgs e)
		{
			// Creation des elements a sauvegarder, couleurs
			ConfigElement xmlElement1 = new ConfigElement("FontColor", m_fontColor.Name);
			ConfigElement xmlElement2 = new ConfigElement("BackColor", m_backColor.Name);
			ConfigElement xmlElement3 = new ConfigElement("BlinkColor", m_blinkColor.Name);

			// Sauvegarde des positions
			ConfigElement xmlElement4 = new ConfigElement("MainX", this.Location.X.ToString());
			ConfigElement xmlElement5 = new ConfigElement("MainY", this.Location.Y.ToString());
			ConfigElement xmlElement6 = new ConfigElement("TimerX", m_timerWindow.Location.X.ToString());
			ConfigElement xmlElement7 = new ConfigElement("TimerY", m_timerWindow.Location.Y.ToString());

			// Sauvegarde de la taille de la fenetre timer
			ConfigElement xmlElement8 = new ConfigElement("TimerWidth", m_timerWindow.Size.Width.ToString());
			ConfigElement xmlElement9 = new ConfigElement("TimerHeight", m_timerWindow.Size.Height.ToString());

			// Sauvegarde du always on top
			ConfigElement xmlElement10 = new ConfigElement("AlwaysOnTop", m_timerWindow.GetAlwaysOnTop().ToString());

			// Minimize in the systray
			ConfigElement xmlElement11 = new ConfigElement("MinimizeSystray", m_minimizeSystray.ToString());

			// Ajout  la collection
			ArrayList elementList = new ArrayList();
			elementList.Add(xmlElement1);
			elementList.Add(xmlElement2);
			elementList.Add(xmlElement3);
			elementList.Add(xmlElement4);
			elementList.Add(xmlElement5);
			elementList.Add(xmlElement6);
			elementList.Add(xmlElement7);
			elementList.Add(xmlElement8);
			elementList.Add(xmlElement9);
			elementList.Add(xmlElement10);
			elementList.Add(xmlElement11);

			// Sauvegarde de la configuration
			mAppConfig.SetConfig(elementList);
			mAppConfig.SaveConfiguration();
		}

		public int GetStartMinutes()
		{
			return m_minutes;
		}

		private void cbxMinimize_CheckedChanged(object sender, System.EventArgs e)
		{
			this.m_minimizeSystray = cbxMinimize.Checked;
		}

		private void cbxAlwaysOnTop_CheckedChanged(object sender, System.EventArgs e)
		{
			this.m_TimerAlwaysOnTop = cbxAlwaysOnTop.Checked;
		}

		private void notifyIcon_DoubleClick(object sender, System.EventArgs e)
		{
			if(!m_disableNotifyClickEvent)
			{
				this.Show();
				this.WindowState = FormWindowState.Normal;
			}
		}

		protected override void OnResize(EventArgs e)
		{
			if(cbxMinimize.Checked && this.WindowState == FormWindowState.Minimized)
			{
				this.Hide();
			}
			base.OnResize(e);
		}

		private void mniExit_Click(object sender, System.EventArgs e)
		{
			//notifyIcon.Visible = false;
			notifyIcon.Dispose();
			frmEveTimer_Closing(sender, null);
			Application.Exit();
		}

		private void mniMinimize_Click(object sender, System.EventArgs e)
		{
			this.WindowState = FormWindowState.Minimized;
		}

		private void mniMaximize_Click(object sender, System.EventArgs e)
		{
			this.Show();
			this.WindowState = FormWindowState.Normal;
		}

		private void mniAggroTimer_Click(object sender, System.EventArgs e)
		{
			StartTimer(3);
		}

		private void mniCriminal_Click(object sender, System.EventArgs e)
		{
			StartTimer(10);
		}

		public void SetMainContextMenu()
		{
			notifyIcon.ContextMenu = ctxMenuMain;
			m_disableNotifyClickEvent = false;
		}

        private void linkLabel1_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            try
            {
                Process.Start(linkLabel1.Text);
            }
            catch (Exception)
            {
                MessageBox.Show("Unable to follow this URL", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error); 
            }
        }

        private void btnResetSettings_Click(object sender, EventArgs e)
        {
            Debug.Assert(m_timerWindow != null, "Form non cre");

            DialogResult result = MessageBox.Show("Reset settings (positions and colors) ?", 
                "Reset settings", MessageBoxButtons.YesNo, MessageBoxIcon.Question);

            if (result == DialogResult.Yes)
            {
                m_timerWindow.ResetLocationAndSize();
            }
        }

        private void btnClearColor_Click(object sender, EventArgs e)
        {
            m_backColor = System.Drawing.SystemColors.Control;
            pnlBackground.BackColor = System.Drawing.SystemColors.Control;
        }
	}
}
